Model Training
================================

This tool trains a model. This requires a KIT internal toolkit or your
own implementation

.. code:: bash

    $ train.py --help
    usage: train.py [-h] [-m FOLDER]

    Create and train a given model.

    optional arguments:
      -h, --help            show this help message and exit
      -m FOLDER, --model FOLDER
                            where is the model folder (with a info.yml)? (default:
                            /home/moose/GitHub/hwr-experiments/models
                            /visualization-smooth-only)

